==> m2w-1.2.4.zip: conf/01_system/plugin.rb <==
# coding: UTF-8
# |Wg:: $Id$

# evOC̃TtBbNX
M2W_COMMAND_PLUGIN_SUFFIX = 'CommandPlugin'
M2W_FORMAT_PLUGIN_SUFFIX = 'FormatPlugin'
M2W_WEBLOG_PLUGIN_SUFFIX = 'WeblogPlugin'

# vOCݒp̃wb_[vtBbNX
M2W_FORMAT_PLUGIN_CONF_HEADER_PREFIX = 'fmt_'

##### vars pꖼ
# vOCʐݒ薼
M2W_FORMAT_PLUGIN_COMMON_CONF_NAME = ':format_plugin_common_conf'

# vOCݒp
M2W_FORMAT_PLUGIN_CONF_NAME = ':format_plugin_conf'

# vOCݒp
M2W_FORMAT_PLUGIN_NAME = ':format_plugin_name'

# vOCʐݒ薼^ftHgl
M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_NAME = 'param_separator'
M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_DEFAULT_VALUE = '/'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_NAME = 'option_separator'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_DEFAULT_VALUE = '@'
M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_NAME = 'quote_char'
M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_DEFAULT_VALUE = '"'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_NAME = 'option_delete_mark'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_DEFAULT_VALUE = '!'

# vOCݒftHgl}bsO
M2W_FORMAT_PLUGIN_CONF_DEFAULT_VALUE = {
	M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_DEFAULT_VALUE,
	M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_DEFAULT_VALUE,
	M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_DEFAULT_VALUE,
	M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_DEFAULT_VALUE,
}

# vOCݒp̃wb_[
M2W_FORMAT_PLUGIN_CONF_HEADER_NAME = ':format_plugin_conf_header'

# EFuOvOCp̃TlCϐ
M2W_WEBLOG_PLUGIN_CONF_THUMBNAIL_VAR_NAME = 'thumbnail'

==> m2w-1.3.5.zip: conf/01_system/plugin.rb <==
# coding: UTF-8
# |Wg:: $Id: plugin.rb 794 2012-08-01 23:35:29Z toy_dev $

# evOC̃TtBbNX
M2W_COMMAND_PLUGIN_SUFFIX = 'CommandPlugin'
M2W_FORMAT_PLUGIN_SUFFIX = 'FormatPlugin'
M2W_WEBLOG_PLUGIN_SUFFIX = 'WeblogPlugin'

# vOCݒp̃wb_[vtBbNX
M2W_FORMAT_PLUGIN_CONF_HEADER_PREFIX = 'fmt_'

##### vars pꖼ
# vOCʐݒ薼
M2W_FORMAT_PLUGIN_COMMON_CONF_NAME = ':format_plugin_common_conf'

# vOCݒp
M2W_FORMAT_PLUGIN_CONF_NAME = ':format_plugin_conf'

# vOCݒp
M2W_FORMAT_PLUGIN_NAME = ':format_plugin_name'

# vOCʐݒ薼^ftHgl
M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_NAME = 'param_separator'
M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_DEFAULT_VALUE = '/'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_NAME = 'option_separator'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_DEFAULT_VALUE = '@'
M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_NAME = 'quote_char'
M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_DEFAULT_VALUE = '"'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_NAME = 'option_delete_mark'
M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_DEFAULT_VALUE = '!'

# vOCݒftHgl}bsO
M2W_FORMAT_PLUGIN_CONF_DEFAULT_VALUE = {
	M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_PARAM_SEPARATOR_DEFAULT_VALUE,
	M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_SEPARATOR_DEFAULT_VALUE,
	M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_QUOTE_CHAR_DEFAULT_VALUE,
	M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_NAME => M2W_FORMAT_PLUGIN_COMMON_CONF_OPTION_DELETE_MARK_DEFAULT_VALUE,
}

# vOCݒp̃wb_[
M2W_FORMAT_PLUGIN_CONF_HEADER_NAME = ':format_plugin_conf_header'

# EFuOvOCp̃TlCϐ
M2W_WEBLOG_PLUGIN_CONF_THUMBNAIL_VAR_NAME = 'thumbnail'
M2W_WEBLOG_PLUGIN_CONF_MEDIAS_VAR_NAME = 'medias'

M2W_WEBLOG_POST_HEADER_ALIAS = {
  'tit' => 'title',
  'dat' => 'dateCreated',
  'desc' => 'description',
  'more' => 'mt_text_more',
  'excerpt' => 'mt_excerpt',
}
